=======
Credits
=======

Development Leads
----------------

* Per Sillrén <pers@spotify.com>
* Erik Stenberg
* Mårten Schultzberg
* Sebastian Ankargren

Contributors
------------

- Per Sillrén (creator) <pers@spotify.com>
- Erik Stenberg
- Mårten Schultzberg
- Sebastian Ankargren
- Chris Halpert (co-creator)
- Eskil Forsell
- Jeremy Salfen
- Kevin Mercurio